Struct memstream::MemStream [] [src]

pub struct MemStream {
    // some fields omitted
}

MemStream is a reader + writer stream backed by an in-memory buffer

Methods

impl MemStream
[src]

fn new() -> MemStream

Creates a new MemStream which can be read and written to

fn eof(&self) -> bool

Tests whether this stream has read all bytes in its ring buffer If true, then this will no longer return bytes from read

fn as_slice<'a>(&'a self) -> &'a [u8]

Acquires an immutable reference to the underlying buffer of this MemStream

fn unwrap(self) -> Vec<u8>

Unwraps this MemStream, returning the underlying buffer